Crate soph_console

Modules

Macros

  • Create an Arg from a usage string.
  • The main macro provided by this crate. See crate documentation for more information.
  • Requires cargo feature flag to be enabled.
  • Select a ValueParser implementation from the intended type

Structs

  • The abstract representation of a command line argument. Used to set all the options and relationships that define a valid argument for the program.
  • Family of related arguments.
  • Container for parse results.
  • Transparent wrapper around a type which implements all the formatters the wrapped type does, with the addition of changing the background color. Recommended to be constructed using OwoColorize.
  • Wrapper around a type which implements all the formatters the wrapped type does, with the addition of changing the background color. Is not recommended unless compile-time coloring is not an option.
  • A wrapper type which applies both a foreground and background color
  • Build a command-line interface.
  • Transparent wrapper around a type which implements all the formatters the wrapped type does, with the addition of changing the foreground color. Recommended to be constructed using OwoColorize.
  • Wrapper around a type which implements all the formatters the wrapped type does, with the addition of changing the foreground color. Is not recommended unless compile-time coloring is not an option.
  • Arg or ArgGroup identifier
  • An error for when the color can not be parsed from a string at runtime
  • Available RGB colors for use with OwoColorize::color or OwoColorize::on_color
  • A pre-computed style that can be applied to a struct using [OwoColorize::style].
  • A wrapper type which applies a Style when displaying the inner type
  • A collection of Styled items that are displayed in such a way as to minimize the amount of characters that are written when displayed.

Enums

Traits

Functions

Type Aliases

Attribute Macros